//-----------------------------------------------------------------------------
/** @file libpentobi_base/PieceTransforms.cpp
    @author Markus Enzenberger
    @copyright GNU General Public License version 3 or later */
//-----------------------------------------------------------------------------

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "PieceTransforms.h"

namespace libpentobi_base {

//-----------------------------------------------------------------------------

PieceTransforms::~PieceTransforms()
{ }

//-----------------------------------------------------------------------------

} // namespace libpentobi_base
